# dcx-pd
_[**D**iscord **C**hat E**x**porter](https://github.com/Tyrrrz/DiscordChatExporter) (by [Tyrrrz](https://github.com/Tyrrrz)) json output parser to typed **P**y**d**antic V2 objects_

**NOTE**: This project has no affiliation with Discord nor Tyrrrz. This was made by another person and is unofficial.
